# PIHAT Widgets

## About

The purpose of this module is to provide a set of programmable visual gadgets that can be used in different projects

The module contains three gadgets

- LedMatrix
- TrafficLight
- LEDCharacter
- LEDMultiCharacter

## Details

### LedMatrix

Displays an LED grid of lights. The colour of each light can be controlled using an RGB tuple

